==> haskell-timeit-2.0-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-timeit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 timeit
version:              2.0
visibility:           public
id:                   timeit-2.0-C5F3nl9E9zYIMscybjdAzR
key:                  timeit-2.0-C5F3nl9E9zYIMscybjdAzR
license:              BSD-3-Clause
copyright:            Copyright © 2009, Lennart Augustsson
maintainer:
    Merijn Verstraaten <merijn@inconsistent.nl>, Lennart Augustsson

author:               Lennart Augustsson
homepage:             https://github.com/merijn/timeit
synopsis:             Time monadic computations with an IO base.
description:
    A simple wrapper to show the used CPU time of monadic computation with an
    IO base.

category:             System
abi:                  4d45f4593a5284797a2bfe84427e07cc
exposed:              True
exposed-modules:      System.TimeIt
import-dirs:          /usr/lib/ghc-8.8.3/site-local/timeit-2.0
library-dirs:         /usr/lib/ghc-8.8.3/site-local/timeit-2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/timeit-2.0
hs-libraries:         HStimeit-2.0-C5F3nl9E9zYIMscybjdAzR
depends:              base-4.13.0.0
haddock-interfaces:   /usr/share/doc/haskell-timeit/html/timeit.haddock
haddock-html:         /usr/share/doc/haskell-timeit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-timeit-2.0-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-timeit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 timeit
version:              2.0
visibility:           public
id:                   timeit-2.0-G1rO4n9EY636waOAdcWrR
key:                  timeit-2.0-G1rO4n9EY636waOAdcWrR
license:              BSD-3-Clause
copyright:            Copyright © 2009, Lennart Augustsson
maintainer:
    Merijn Verstraaten <merijn@inconsistent.nl>, Lennart Augustsson

author:               Lennart Augustsson
homepage:             https://github.com/merijn/timeit
synopsis:             Time monadic computations with an IO base.
description:
    A simple wrapper to show the used CPU time of monadic computation with an
    IO base.

category:             System
abi:                  cdf20829e3f2bbad02c33bfdca76387e
exposed:              True
exposed-modules:      System.TimeIt
import-dirs:          /usr/lib/ghc-8.10.1/site-local/timeit-2.0
library-dirs:         /usr/lib/ghc-8.10.1/site-local/timeit-2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/timeit-2.0
hs-libraries:         HStimeit-2.0-G1rO4n9EY636waOAdcWrR
depends:              base-4.14.0.0
haddock-interfaces:   /usr/share/doc/haskell-timeit/html/timeit.haddock
haddock-html:         /usr/share/doc/haskell-timeit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
